# Table of Contents

- [milestones](<./milestones.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Milestones](<./Milestones.md>)
  - [Add Milestones](<./Milestones/Add-Milestones.md>)
  - [Edit and Delete Milestones](<./Milestones/Edit-and-Delete-Milestones.md>)
  - [Lifecycle and Cross-Project Referencing of Milestones](<./Milestones/Lifecycle-and-Cross-Project-Referencing-of-Milestones.md>)
  - [Visualizing Milestones in Reports](<./Milestones/Visualizing-Milestones-in-Reports.md>)
